@@ -22,11 +22,12 @@ if not os.path.exists(root):
 gfwlist_path = os.path.join(root, "gfwlist.txt")
 whitelist_path = os.path.join(root, "whitelist.txt")
 
+
 cache: set = set()
 
 
 class FilterRule(metaclass=Singleton):
-    def __init__(self, yourselfs: typing.Sequence[str] = None) -> None:
+    def __init__(self, yourselfs: typing.Sequence[str] = []) -> None:
         self.black_list = (
             re.compile(
                 r".*?google\.(ac|ad|ae|af|al|am|as|at|az|ba|be|bf|bg|bi|bj|bs|bt|by|ca|cat|cd|cf|cg|ch|ci|cl|cm|co.ao|co.bw|co.ck|co.cr|co.id|co.il|co.in|co.jp|co.ke|co.kr|co.ls|co.ma|com|com.af|com.ag|com.ai|com.ar|com.au|com.bd|com.bh|com.bn|com.bo|com.br|com.bz|com.co|com.cu|com.cy|com.do|com.ec|com.eg|com.et|com.fj|com.gh|com.gi|com.gt|com.hk|com.jm|com.kh|com.kw|com.lb|com.ly|com.mm|com.mt|com.mx|com.my|com.na|com.nf|com.ng|com.ni|com.np|com.om|com.pa|com.pe|com.pg|com.ph|com.pk|com.pr|com.py|com.qa|com.sa|com.sb|com.sg|com.sl|com.sv|com.tj|com.tr|com.tw|com.ua|com.uy|com.vc|com.vn|co.mz|co.nz|co.th|co.tz|co.ug|co.uk|co.uz|co.ve|co.vi|co.za|co.zm|co.zw|cv|cz|de|dj|dk|dm|dz|ee|es|eu|fi|fm|fr|ga|ge|gg|gl|gm|gp|gr|gy|hk|hn|hr|ht|hu|ie|im|iq|is|it|it.ao|je|jo|kg|ki|kz|la|li|lk|lt|lu|lv|md|me|mg|mk|ml|mn|ms|mu|mv|mw|mx|ne|nl|no|nr|nu|org|pl|pn|ps|pt|ro|rs|ru|rw|sc|se|sh|si|sk|sm|sn|so|sr|st|td|tg|tk|tl|tm|tn|to|tt|us|vg|vn|vu|ws)"
@@ -62,9 +63,9 @@ class FilterRule(metaclass=Singleton):
     @staticmethod
     def open(filepath: str) -> typing.Generator:
         try:
-            file = open(filepath, "r")
-            for line in file.readlines():
-                yield line.strip()
+            with open(filepath, "r") as file:
+                for line in file.readlines():
+                    yield line.strip()
         except FileNotFoundError:
             pass
 
